<?php 
/*
 * Plugin Name: WODTogether Whiteboards
 * Plugin URI: http://wodtogether.com
 * Description: Automatic embedding of WODTogether whiteboards into blog posts
 * Version: 2.0.1
 * Author: WODTogether, Inc.
 * Author URI: http://wodtogether.com
 */

if (!function_exists('add_action')) {
	echo "Hi there!  I'm just a plugin, not much I can do when called directly.";
	exit;
}


/**
 * WODTogether Settings
 */
add_action('admin_menu', 'wodtogether_admin_add_page');
function wodtogether_admin_add_page() {
	add_options_page('WODTogether Plugin Page', 'WODTogether', 'manage_options', 'plugin', 'wodtogether_options_page');
}

function wodtogether_options_page() {
	echo "<div>
	<h2>WODTogether Plugin Settings</h2>
	For help visit: <a href=\"http://wodtogether.uservoice.com/knowledgebase/articles/71819-wordpress-plugin\">http://wodtogether.uservoice.com</a>
	<form action=\"options.php\" method=\"post\">";
	
	settings_fields('wodtogether_options');
	do_settings_sections('wodtogether'); 
	
	echo "<input class='button-primary' name=\"Submit\" type=\"submit\" value=\"Save Changes\" /></form></div>";
}

add_action('admin_init', 'wodtogether_admin_init');
function wodtogether_admin_init(){
	register_setting( 'wodtogether_options', 'wodtogether_options', 'wodtogether_options_validate' );
	add_settings_section('wodtogether_main', 'Main Settings', 'wodtogether_section_text', 'wodtogether');
	
	add_settings_field('wodtogether_gym_id', 'Gym ID', 'wodtogether_setting_gym_id', 'wodtogether', 'wodtogether_main');
	add_settings_field('wodtogether_date_offset', 'Whiteboard Date Setting', 'wodtogether_setting_date_offset', 'wodtogether', 'wodtogether_main');
	add_settings_field('wodtogether_required_category', 'Required Category', 'wodtogether_setting_required_category', 'wodtogether', 'wodtogether_main');
	add_settings_field('wodtogether_iframe_height', 'iFrame Height (in pixels)', 'wodtogether_setting_iframe_height', 'wodtogether', 'wodtogether_main');
	add_settings_field('wodtogether_auto_resize', 'Attempt Auto-Resize', 'wodtogether_setting_auto_resize', 'wodtogether', 'wodtogether_main');
	add_settings_field('wodtogether_show_wods', 'Show WOD Details by Default', 'wodtogether_setting_show_wods', 'wodtogether', 'wodtogether_main');
}

function wodtogether_section_text() {
	echo '<p>WODTogether Integration Settings</p>';
}

function wodtogether_setting_gym_id() {
	$options = get_option('wodtogether_options');
	echo "<input id='wodtogether_gym_id' name='wodtogether_options[gym_id]' size='20' type='text' value='{$options['gym_id']}' />
	<p><strong>Note:</strong> Find your gym ID by going to <em>My Gym &raquo; Recent Activity</em> on <a href=\"http://wodtogether.com\">WODTogether</a>. The URL (address bar) will look like: http://wodtogether.com/gym/view/id/<strong>####</strong> -- copy that number, it's your gym id.</p>";
}
function wodtogether_setting_date_offset() {
	$options = get_option('wodtogether_options');

	$selected = (isset($options['date_offset']) && $options['date_offset']) ? ' selected' : '';
	echo "<select style='width:200px' id='wodtogether_date_offset' name='wodtogether_options[date_offset]'><option value='0'>Same Day as Blog Post</option><option value='1' {$selected}>Day After Blog Post</option></select>
	<p><strong>Note:</strong> If you publish your workouts the day or night before, use \"Day After Blog Post\"</p>";
}
function wodtogether_setting_required_category() {
	$options = get_option('wodtogether_options');
	echo "<select id='wodtogether_required_category' name='wodtogether_options[required_category]'><option value=''>Embed Whiteboards on All Blog Posts </option>";
	
	$blog_categories = get_categories(array('hide_empty' => 0));
	
	foreach($blog_categories as $category) {
		$selected = ($options['required_category'] == $category->term_id) ? ' selected' : '';
		echo "<option value=\"{$category->term_id}\"{$selected}>{$category->name}</option>";
	}
	
	echo "</select>";
}
function wodtogether_setting_iframe_height() {
	$options = get_option('wodtogether_options');
	if (!$options['iframe_height']) {
		$options['iframe_height'] = 700;
	}
	echo "<input id='wodtogether_iframe_height' name='wodtogether_options[iframe_height]' size='20' type='text' value='{$options['iframe_height']}' />";
}
function wodtogether_setting_auto_resize() {
	$options = get_option('wodtogether_options');
	
	$checked = (isset($options['auto_resize']) && $options['auto_resize']) ? ' checked' : '';
	echo "<input id='wodtogether_auto_resize' name='wodtogether_options[auto_resize]' {$checked} type='checkbox' value='1' />
	<p><strong>Recommended!</strong> This will attempt to automatically resize the whiteboard iframe so there are no scrollbars.</p>";
}
function wodtogether_setting_show_wods() {
	$options = get_option('wodtogether_options');
	
	$checked = (isset($options['show_wods']) && $options['show_wods']) ? ' checked' : '';
	echo "<input id='wodtogether_show_wods' name='wodtogether_options[show_wods]' {$checked} type='checkbox' value='1' />";
}


function wodtogether_options_validate($input) {
	if (!is_numeric($input['gym_id'])) {
		$input['gym_id'] = 2958; // default to main site
	}
	
	if (!is_numeric($input['date_offset'])) {
		$input['date_offset'] = 0; // default to same day
	}
	
	if (!is_numeric($input['iframe_height'])) {
		$input['date_offset'] = 700; // default to 700
	}
	
	if (!is_numeric($input['show_wods'])) {
		$input['show_wods'] = 0; // default to off
	}
	
	$input['required_category'] = trim($input['required_category']);
	
	return $input;
}
/**
 * END WODTogether Settings
 */
 
// count how many whiteboards have been loaded for this page
$whiteboarded = 0;
$wodtogetherSettings = get_option('wodtogether_options');
$wodv = time();
wp_register_style('wodtogether-shadowbox', 'http://wodtogether.com/js/shadowbox-3.0.3/shadowbox.css');
wp_enqueue_style('wodtogether-shadowbox');

wp_register_style('wodtogether-whiteboards', WP_PLUGIN_URL . '/wodtogether-whiteboards/wodtogether-whiteboards.css?v='. $wodv);
wp_enqueue_style('wodtogether-whiteboards');

wp_enqueue_script('wodtogether-shadowbox',
	'http://wodtogether.com/js/shadowbox-3.0.3/shadowbox.js?v='. $wodv,
	array('jquery')
);
wp_enqueue_script('wodtogether-whiteboards',
	WP_PLUGIN_URL . '/wodtogether-whiteboards/wodtogether-whiteboards.js?v='. $wodv,
	array('jquery')
);

/**
 * Show whiteboard on each post
 */
add_filter('the_content', 'showWhiteboard');
function showWhiteboard($input)
{
	global $whiteboarded;
	global $wodtogetherSettings;
	
	if (isset($wodtogetherSettings['required_category']) && $wodtogetherSettings['required_category']) {
		$post_categories = get_the_category();
		$has_required_category = false;
		foreach($post_categories as $post_category) {
			if ($post_category->term_id == $wodtogetherSettings['required_category']) {
				$has_required_category = true;
			}
		}
		
		if (!$has_required_category) {
			return $input;
		}
	}
	
	$gym_id =(!isset($wodtogetherSettings['gym_id']) || !$wodtogetherSettings['gym_id'] || !is_numeric($wodtogetherSettings['gym_id'])) ? 2958 : $wodtogetherSettings['gym_id']; 
	$show_wods = (isset($wodtogetherSettings['show_wods']) && $wodtogetherSettings['show_wods']) ? '/show-wods/1' : '';
	
	$date_offset = (isset($wodtogetherSettings['date_offset']) && $wodtogetherSettings['date_offset']) ? 86400 : 0;	
	$date = date('Y-m-d', strtotime($GLOBALS['post']->post_date) + $date_offset);
	
	// show a max of 5 whiteboards per screen
	if ($whiteboarded >= 5) {
		return $input . "<br /><a href=\"http://wodtogether.com/whiteboard/view/date/{$date}/gym/{$gym_id}/embed/remote{$show_wods}\">View Whitebaord</a>";
	} 
	
	$wbs = file_get_contents("http://api.wodtogether.com/?method=whiteboardSelect&wo_only=1&gym_id={$gym_id}&date={$date}&client_id=wodtogetherwp&client_secret=an7a7233nan298naui", false);
	if ($wbs) {
		try {
			$wb_data = json_decode($wbs);
		} catch (Exception $e) {
			$wb_data = false;
		}
	}
	
	if (isset($wb_data->message)) {
		$wb_data = false;
	}
	
	$whiteboardsHtml = '';
	if ($wb_data) {
		$whiteboardsHtml .= "<div id=\"wodtogether_wbs\">";
		foreach ($wb_data as $wb) {
			$whiteboardsHtml .= "<div class=\"wodtogether_wb\"><h1>WODs <button class=\"wodtogether_wb_button btn btn-large\" data-gymid=\"{$gym_id}\" data-date=\"{$date}\">Open Whiteboard</button></h1>";
			if ($wb->name) {
				$whiteboardsHtml .= "<h2>{$wb->name}</h2>";
			}
			if ($wb->comments) {
				$whiteboardsHtml .= "<p class=\"wodtogether_wb_comments\"></p>";
			}

			foreach ($wb->workouts as $workout) {
				$workoutId = $workout->id;
				$malerx = $wb->workoutDetails->{$workoutId}->malerx;
				$femalerx = $wb->workoutDetails->{$workoutId}->femalerx;
				if (empty($femalerx)) {
					$femalerx = $malerx;
				}
				
				$whiteboardsHtml .= "<div class=\"wodtogether_wo\">
					<h3>{$workout->name}</h3>
					<div class=\"wodtogether_wo_rx\"><strong>Male Rx</strong><br />{$malerx}</div>
					<div class=\"wodtogether_wo_rx\"><strong>Female Rx</strong><br />{$femalerx}</div>
				</div>
				<div class=\"wodtogether_wo_spacer\">&nbsp;</div>";
			}
			$whiteboardsHtml .= "</div>";
		}
		$whiteboardsHtml .= "</div>";
	}
	
	$whiteboarded++;
	// $whiteboardIframeHtml = "<br /> <iframe width=\"98%\" height=\"{$height}\" src=\"http://wodtogether.com/whiteboard/view/date/{$date}/gym/{$gym_id}/embed/remote{$show_wods}\" id=\"wb_{$date}_{$gym_id}\"></iframe>";	
	//$whiteboardIframeHtml = "<br /> <div class=\"wodtogether_whiteboard_container\" data-gymid=\"{$gym_id}\" data-date=\"{$date}\"></div>";
	return $input . $whiteboardsHtml;
}
